@@ -8,7 +8,7 @@ The core `queries.Queries` class will automatically register support for UUIDs,
 Unicode and Unicode arrays.
 
 """
-__version__ = '1.2.1'
+__version__ = '1.3.0'
 version = __version__
 
 import logging
@@ -63,9 +63,11 @@ def uri(host='localhost', port=5432, dbname='postgres', user='postgres',
     :return str: The PostgreSQL connection URI
 
     """
+    if port:
+        host = '%s:%s' % (host, port)
     if password:
-        return 'postgresql://%s:%s@%s:%i/%s' % (user, password, host, port, dbname)
-    return 'postgresql://%s@%s:%i/%s' % (user, host, port, dbname)
+        return 'postgresql://%s:%s@%s/%s' % (user, password, host, dbname)
+    return 'postgresql://%s@%s/%s' % (user, host, dbname)
 
 
 # For ease of access to different cursor types
